NullableRunesExtensions extension
- on
Methods
-
firstOrNull(
) → int? -
Available on Runes?, provided by the NullableRunesExtensions extension
Returns the first rune or null if the runes is null or empty. -
hasValue(
) → bool -
Available on Runes?, provided by the NullableRunesExtensions extension
Checks if the runes has a value (is not null and not empty). -
isNullOrEmpty(
) → bool -
Available on Runes?, provided by the NullableRunesExtensions extension
Checks if the runes is null or empty. -
joinAsString(
[String separator = '']) → String -
Available on Runes?, provided by the NullableRunesExtensions extension
Joins the runes into a string, using the provided separator. -
lastOrNull(
) → int? -
Available on Runes?, provided by the NullableRunesExtensions extension
Returns the last rune or null if the runes is null or empty. -
map<
T> (T transform(int)) → Iterable< T> -
Available on Runes?, provided by the NullableRunesExtensions extension
Maps each rune to a new value using the provided transform function. -
orEmpty(
) → Runes -
Available on Runes?, provided by the NullableRunesExtensions extension
Returns the runes if it is not null, otherwise returns an empty runes.